==> operation-prime-2.0.5-20140327.172558-1-sources.jar: org/gcube/data/analysis/tabulardata/operation/column/SimpleTextTypedColumnTypeTransformationFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.column;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.model.column.Column;
import org.gcube.data.analysis.tabulardata.model.column.ColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.AnnotationColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.AttributeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeDescriptionColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeNameColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.MeasureColumnType;
import org.gcube.data.analysis.tabulardata.model.datatype.TextType;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.validation.ColumnTypeCastValidatorFactory;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

import com.google.common.collect.Lists;

@Singleton
public abstract class SimpleTextTypedColumnTypeTransformationFactory extends ChangeColumnTypeTransformationFactory {

	public final static List<Class<? extends ColumnType>> allowedSourceColumnTypes = Lists.newArrayList();

	private static final List<Parameter> parameters=new ArrayList<>();
	
	static {
		allowedSourceColumnTypes.add(AnnotationColumnType.class);
		allowedSourceColumnTypes.add(MeasureColumnType.class);
		allowedSourceColumnTypes.add(AttributeColumnType.class);
		allowedSourceColumnTypes.add(CodeColumnType.class);
		allowedSourceColumnTypes.add(CodeNameColumnType.class);
		allowedSourceColumnTypes.add(CodeDescriptionColumnType.class);
		
		parameters.add(ADDITIONAL_META_PARAMETER);
	}

	private DatabaseConnectionProvider connectionProvider;
	
	private CubeManager cubeManager;

	public SimpleTextTypedColumnTypeTransformationFactory(CubeManager cubeManager, DatabaseConnectionProvider connectionProvider) {
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
	}

	@Override
	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation,cubeManager);
		invocation.getParameterInstances().put(ColumnTypeCastValidatorFactory.TARGET_TYPE_PARAMETER.getIdentifier(), new TextType() );
		return new SimpleTextTypedColumnTypeTransformation(invocation, cubeManager, connectionProvider, getManagedColumnType());
	}

	protected List<Class<? extends ColumnType>> getAllowedSourceColumnTypes() {
		return allowedSourceColumnTypes;
	}

	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}
	
	private void checkTargetColumnEligibility(OperationInvocation invocation) throws InvalidInvocationException {
		Table targetTable = cubeManager.getTable(invocation.getTargetTableId());
		Column targetColumn = targetTable.getColumnById(invocation.getTargetColumnId());
		if (!getAllowedSourceColumnTypes().contains(targetColumn.getColumnType().getClass()))
			throw new InvalidInvocationException(invocation, "Source column is not of a valid type: " + targetColumn.getColumnType());
		if (targetColumn.getColumnType().equals(getManagedColumnType()))
			throw new InvalidInvocationException(invocation,"Source column is already of type " + getManagedColumnType().getName());
		
	}
}

==> operation-prime-2.0.7-20140408.133542-3-sources.jar: org/gcube/data/analysis/tabulardata/operation/column/SimpleTextTypedColumnTypeTransformationFactory.java <==
package org.gcube.data.analysis.tabulardata.operation.column;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Singleton;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.cube.data.connection.DatabaseConnectionProvider;
import org.gcube.data.analysis.tabulardata.model.column.ColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.AnnotationColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.AttributeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeDescriptionColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.CodeNameColumnType;
import org.gcube.data.analysis.tabulardata.model.column.type.MeasureColumnType;
import org.gcube.data.analysis.tabulardata.model.datatype.TextType;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.parameters.Parameter;
import org.gcube.data.analysis.tabulardata.operation.validation.ColumnTypeCastValidatorFactory;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.InvalidInvocationException;

import com.google.common.collect.Lists;

@Singleton
public abstract class SimpleTextTypedColumnTypeTransformationFactory extends ChangeColumnTypeTransformationFactory {

	public final static List<ColumnType> allowedSourceColumnTypes = Lists.newArrayList();

	private static final List<Parameter> parameters=new ArrayList<>();
	
	static {
		allowedSourceColumnTypes.add(new AnnotationColumnType());
		allowedSourceColumnTypes.add(new MeasureColumnType());
		allowedSourceColumnTypes.add(new AttributeColumnType());
		allowedSourceColumnTypes.add(new CodeColumnType());
		allowedSourceColumnTypes.add(new CodeNameColumnType());
		allowedSourceColumnTypes.add(new CodeDescriptionColumnType());
		
		parameters.add(ADDITIONAL_META_PARAMETER);
	}

	private DatabaseConnectionProvider connectionProvider;
	
	private CubeManager cubeManager;

	public SimpleTextTypedColumnTypeTransformationFactory(CubeManager cubeManager, DatabaseConnectionProvider connectionProvider) {
		this.cubeManager = cubeManager;
		this.connectionProvider = connectionProvider;
	}

	@Override
	public Worker createWorker(OperationInvocation invocation) throws InvalidInvocationException {
		performBaseChecks(invocation,cubeManager);
		checkAllowedColumnTypeTransition(invocation, cubeManager);
		invocation.getParameterInstances().put(ColumnTypeCastValidatorFactory.TARGET_TYPE_PARAMETER.getIdentifier(), new TextType() );
		return new SimpleTextTypedColumnTypeTransformation(invocation, cubeManager, connectionProvider, getManagedColumnType());
	}

	protected List<ColumnType> getAllowedSourceColumnTypes() {
		return allowedSourceColumnTypes;
	}

	@Override
	protected List<Parameter> getParameters() {
		return parameters;
	}
	

}
